from __future__ import absolute_import

import re  # noqa: F401
import six

from ionoscloud.api_client import ApiClient
from ionoscloud.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DataCentersApi(object):

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def datacenters_delete(self, datacenter_id, **kwargs):  # noqa: E501
        """Delete data centers  # noqa: E501

        Delete the specified data center and all the elements it contains. This method is destructive and should be used carefully.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_delete(datacenter_id, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_delete_with_http_info(datacenter_id, **kwargs)  # noqa: E501

    def datacenters_delete_with_http_info(self, datacenter_id, **kwargs):  # noqa: E501
        """Delete data centers  # noqa: E501

        Delete the specified data center and all the elements it contains. This method is destructive and should be used carefully.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_delete_with_http_info(datacenter_id, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = [
            'datacenter_id',
            'pretty',
            'depth',
            'x_contract_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_delete" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']
        # verify the required parameter 'datacenter_id' is set
        if self.api_client.client_side_validation and ('datacenter_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter_id` when calling `datacenters_delete`")  # noqa: E501

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_delete`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_delete`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'datacenter_id' in local_var_params:
            path_params['datacenterId'] = local_var_params['datacenter_id']  # noqa: E501

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = None
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters/{datacenterId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def datacenters_find_by_id(self, datacenter_id, **kwargs):  # noqa: E501
        """Retrieve data centers  # noqa: E501

        Retrieve data centers by resource ID. This value is in the response body when the data center is created, and in the list of the data centers, returned by GET.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_find_by_id(datacenter_id, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Datacenter
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_find_by_id_with_http_info(datacenter_id, **kwargs)  # noqa: E501

    def datacenters_find_by_id_with_http_info(self, datacenter_id, **kwargs):  # noqa: E501
        """Retrieve data centers  # noqa: E501

        Retrieve data centers by resource ID. This value is in the response body when the data center is created, and in the list of the data centers, returned by GET.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_find_by_id_with_http_info(datacenter_id, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Datacenter, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'datacenter_id',
            'pretty',
            'depth',
            'x_contract_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_find_by_id" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']
        # verify the required parameter 'datacenter_id' is set
        if self.api_client.client_side_validation and ('datacenter_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter_id` when calling `datacenters_find_by_id`")  # noqa: E501

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_find_by_id`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_find_by_id`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'datacenter_id' in local_var_params:
            path_params['datacenterId'] = local_var_params['datacenter_id']  # noqa: E501

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = 'Datacenter'
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters/{datacenterId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def datacenters_get(self, **kwargs):  # noqa: E501
        """List your data centers  # noqa: E501

        List the data centers for your account. Default limit is the first 100 items; use pagination query parameters for listing more items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_get(async_req=True)
        >>> result = thread.get()

        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param offset: The first element (from the complete list of the elements) to include in the response (used together with <b><i>limit</i></b> for pagination).
        :type offset: int
        :param limit: The maximum number of elements to return (use together with offset for pagination).
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Datacenters
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_get_with_http_info(**kwargs)  # noqa: E501

    def datacenters_get_with_http_info(self, **kwargs):  # noqa: E501
        """List your data centers  # noqa: E501

        List the data centers for your account. Default limit is the first 100 items; use pagination query parameters for listing more items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param offset: The first element (from the complete list of the elements) to include in the response (used together with <b><i>limit</i></b> for pagination).
        :type offset: int
        :param limit: The maximum number of elements to return (use together with offset for pagination).
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Datacenters, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'pretty',
            'depth',
            'x_contract_number',
            'offset',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_get" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_get`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_get`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `datacenters_get`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 10000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `datacenters_get`, must be a value less than or equal to `10000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `datacenters_get`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = 'Datacenters'
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def datacenters_patch(self, datacenter_id, datacenter, **kwargs):  # noqa: E501
        """Partially modify a Data Center by ID  # noqa: E501

        Updates the properties of the specified data center, rename it, or change the description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_patch(datacenter_id, datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param datacenter: The properties of the data center to be updated. (required)
        :type datacenter: DatacenterProperties
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Datacenter
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_patch_with_http_info(datacenter_id, datacenter, **kwargs)  # noqa: E501

    def datacenters_patch_with_http_info(self, datacenter_id, datacenter, **kwargs):  # noqa: E501
        """Partially modify a Data Center by ID  # noqa: E501

        Updates the properties of the specified data center, rename it, or change the description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_patch_with_http_info(datacenter_id, datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param datacenter: The properties of the data center to be updated. (required)
        :type datacenter: DatacenterProperties
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Datacenter, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'datacenter_id',
            'datacenter',
            'pretty',
            'depth',
            'x_contract_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_patch" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']
        # verify the required parameter 'datacenter_id' is set
        if self.api_client.client_side_validation and ('datacenter_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter_id` when calling `datacenters_patch`")  # noqa: E501
        # verify the required parameter 'datacenter' is set
        if self.api_client.client_side_validation and ('datacenter' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter` when calling `datacenters_patch`")  # noqa: E501

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_patch`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_patch`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'datacenter_id' in local_var_params:
            path_params['datacenterId'] = local_var_params['datacenter_id']  # noqa: E501

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'datacenter' in local_var_params:
            body_params = local_var_params['datacenter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = 'Datacenter'
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters/{datacenterId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def datacenters_post(self, datacenter, **kwargs):  # noqa: E501
        """Create a Data Center  # noqa: E501

        Creates new data centers, and data centers that already contain elements, such as servers and storage volumes.  Virtual data centers are the foundation of the platform; they act as logical containers for all other objects you create, such as servers and storage volumes. You can provision as many data centers as needed. Data centers have their own private networks and are logically segmented from each other to create isolation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_post(datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter: The data center to create. (required)
        :type datacenter: Datacenter
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Datacenter
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_post_with_http_info(datacenter, **kwargs)  # noqa: E501

    def datacenters_post_with_http_info(self, datacenter, **kwargs):  # noqa: E501
        """Create a Data Center  # noqa: E501

        Creates new data centers, and data centers that already contain elements, such as servers and storage volumes.  Virtual data centers are the foundation of the platform; they act as logical containers for all other objects you create, such as servers and storage volumes. You can provision as many data centers as needed. Data centers have their own private networks and are logically segmented from each other to create isolation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_post_with_http_info(datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter: The data center to create. (required)
        :type datacenter: Datacenter
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Datacenter, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'datacenter',
            'pretty',
            'depth',
            'x_contract_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_post" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']
        # verify the required parameter 'datacenter' is set
        if self.api_client.client_side_validation and ('datacenter' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter` when calling `datacenters_post`")  # noqa: E501

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_post`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_post`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'datacenter' in local_var_params:
            body_params = local_var_params['datacenter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = 'Datacenter'
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def datacenters_put(self, datacenter_id, datacenter, **kwargs):  # noqa: E501
        """Modify a Data Center by ID  # noqa: E501

        Modifies the properties of the specified data center, rename it, or change the description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_put(datacenter_id, datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param datacenter: The modified data center. (required)
        :type datacenter: Datacenter
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Datacenter
        """
        kwargs['_return_http_data_only'] = True
        return self.datacenters_put_with_http_info(datacenter_id, datacenter, **kwargs)  # noqa: E501

    def datacenters_put_with_http_info(self, datacenter_id, datacenter, **kwargs):  # noqa: E501
        """Modify a Data Center by ID  # noqa: E501

        Modifies the properties of the specified data center, rename it, or change the description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datacenters_put_with_http_info(datacenter_id, datacenter, async_req=True)
        >>> result = thread.get()

        :param datacenter_id: The unique ID of the data center. (required)
        :type datacenter_id: str
        :param datacenter: The modified data center. (required)
        :type datacenter: Datacenter
        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
        :type pretty: bool
        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
        :type depth: int
        :param x_contract_number: Users with multiple contracts must provide the contract number, for which all API requests are to be executed.
        :type x_contract_number: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Datacenter, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'datacenter_id',
            'datacenter',
            'pretty',
            'depth',
            'x_contract_number'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                'response_type',
                'query_params'
            ]
        )

        for local_var_params_key, local_var_params_val in six.iteritems(local_var_params['kwargs']):
            if local_var_params_key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method datacenters_put" % local_var_params_key
                )
            local_var_params[local_var_params_key] = local_var_params_val
        del local_var_params['kwargs']
        # verify the required parameter 'datacenter_id' is set
        if self.api_client.client_side_validation and ('datacenter_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter_id` when calling `datacenters_put`")  # noqa: E501
        # verify the required parameter 'datacenter' is set
        if self.api_client.client_side_validation and ('datacenter' not in local_var_params or  # noqa: E501
                                                        local_var_params['datacenter'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `datacenter` when calling `datacenters_put`")  # noqa: E501

        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] > 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_put`, must be a value less than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'depth' in local_var_params and local_var_params['depth'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `depth` when calling `datacenters_put`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'datacenter_id' in local_var_params:
            path_params['datacenterId'] = local_var_params['datacenter_id']  # noqa: E501

        query_params = list(local_var_params.get('query_params', {}).items())
        if 'pretty' in local_var_params and local_var_params['pretty'] is not None:  # noqa: E501
            query_params.append(('pretty', local_var_params['pretty']))  # noqa: E501
        if 'depth' in local_var_params and local_var_params['depth'] is not None:  # noqa: E501
            query_params.append(('depth', local_var_params['depth']))  # noqa: E501

        header_params = {}
        if 'x_contract_number' in local_var_params:
            header_params['X-Contract-Number'] = local_var_params['x_contract_number']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'datacenter' in local_var_params:
            body_params = local_var_params['datacenter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501

        response_type = 'Datacenter'
        if 'response_type' in kwargs:
            response_type = kwargs['response_type']

        return self.api_client.call_api(
            '/datacenters/{datacenterId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=response_type,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class TargetGroupTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'health_check_enabled': 'bool',

        'ip': 'str',

        'maintenance_enabled': 'bool',

        'port': 'int',

        'weight': 'int',

        'proxy_protocol': 'str',
    }

    attribute_map = {

        'health_check_enabled': 'healthCheckEnabled',

        'ip': 'ip',

        'maintenance_enabled': 'maintenanceEnabled',

        'port': 'port',

        'weight': 'weight',

        'proxy_protocol': 'proxyProtocol',
    }

    def __init__(self, health_check_enabled=None, ip=None, maintenance_enabled=None, port=None, weight=None, proxy_protocol='none', local_vars_configuration=None):  # noqa: E501
        """TargetGroupTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._health_check_enabled = None
        self._ip = None
        self._maintenance_enabled = None
        self._port = None
        self._weight = None
        self._proxy_protocol = None
        self.discriminator = None

        if health_check_enabled is not None:
            self.health_check_enabled = health_check_enabled
        self.ip = ip
        if maintenance_enabled is not None:
            self.maintenance_enabled = maintenance_enabled
        self.port = port
        self.weight = weight
        if proxy_protocol is not None:
            self.proxy_protocol = proxy_protocol


    @property
    def health_check_enabled(self):
        """Gets the health_check_enabled of this TargetGroupTarget.  # noqa: E501

        When the health check is enabled, the target is available only when it accepts regular TCP or HTTP connection attempts for state checking. The state check consists of one connection attempt with the target's address and port. The default value is 'TRUE'.  # noqa: E501

        :return: The health_check_enabled of this TargetGroupTarget.  # noqa: E501
        :rtype: bool
        """
        return self._health_check_enabled

    @health_check_enabled.setter
    def health_check_enabled(self, health_check_enabled):
        """Sets the health_check_enabled of this TargetGroupTarget.

        When the health check is enabled, the target is available only when it accepts regular TCP or HTTP connection attempts for state checking. The state check consists of one connection attempt with the target's address and port. The default value is 'TRUE'.  # noqa: E501

        :param health_check_enabled: The health_check_enabled of this TargetGroupTarget.  # noqa: E501
        :type health_check_enabled: bool
        """

        self._health_check_enabled = health_check_enabled

    @property
    def ip(self):
        """Gets the ip of this TargetGroupTarget.  # noqa: E501

        The IP address of the balanced target.  # noqa: E501

        :return: The ip of this TargetGroupTarget.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this TargetGroupTarget.

        The IP address of the balanced target.  # noqa: E501

        :param ip: The ip of this TargetGroupTarget.  # noqa: E501
        :type ip: str
        """
        if self.local_vars_configuration.client_side_validation and ip is None:  # noqa: E501
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def maintenance_enabled(self):
        """Gets the maintenance_enabled of this TargetGroupTarget.  # noqa: E501

        When the maintenance mode is enabled, the target is prevented from receiving traffic; the default value is 'FALSE'.  # noqa: E501

        :return: The maintenance_enabled of this TargetGroupTarget.  # noqa: E501
        :rtype: bool
        """
        return self._maintenance_enabled

    @maintenance_enabled.setter
    def maintenance_enabled(self, maintenance_enabled):
        """Sets the maintenance_enabled of this TargetGroupTarget.

        When the maintenance mode is enabled, the target is prevented from receiving traffic; the default value is 'FALSE'.  # noqa: E501

        :param maintenance_enabled: The maintenance_enabled of this TargetGroupTarget.  # noqa: E501
        :type maintenance_enabled: bool
        """

        self._maintenance_enabled = maintenance_enabled

    @property
    def port(self):
        """Gets the port of this TargetGroupTarget.  # noqa: E501

        The port of the balanced target service; the valid range is 1 to 65535.  # noqa: E501

        :return: The port of this TargetGroupTarget.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this TargetGroupTarget.

        The port of the balanced target service; the valid range is 1 to 65535.  # noqa: E501

        :param port: The port of this TargetGroupTarget.  # noqa: E501
        :type port: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def weight(self):
        """Gets the weight of this TargetGroupTarget.  # noqa: E501

        The traffic is distributed proportionally to target weight, which is the ratio of the total weight of all targets. A target with higher weight receives a larger share of traffic. The valid range is from 0 to 256; the default value is '1'. Targets with a weight of '0' do not participate in load balancing but still accept persistent connections. We recommend using values in the middle range to leave room for later adjustments.  # noqa: E501

        :return: The weight of this TargetGroupTarget.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this TargetGroupTarget.

        The traffic is distributed proportionally to target weight, which is the ratio of the total weight of all targets. A target with higher weight receives a larger share of traffic. The valid range is from 0 to 256; the default value is '1'. Targets with a weight of '0' do not participate in load balancing but still accept persistent connections. We recommend using values in the middle range to leave room for later adjustments.  # noqa: E501

        :param weight: The weight of this TargetGroupTarget.  # noqa: E501
        :type weight: int
        """
        if self.local_vars_configuration.client_side_validation and weight is None:  # noqa: E501
            raise ValueError("Invalid value for `weight`, must not be `None`")  # noqa: E501

        self._weight = weight

    @property
    def proxy_protocol(self):
        """Gets the proxy_protocol of this TargetGroupTarget.  # noqa: E501

        ProxyProtocol is used to set the proxy protocol version.  # noqa: E501

        :return: The proxy_protocol of this TargetGroupTarget.  # noqa: E501
        :rtype: str
        """
        return self._proxy_protocol

    @proxy_protocol.setter
    def proxy_protocol(self, proxy_protocol):
        """Sets the proxy_protocol of this TargetGroupTarget.

        ProxyProtocol is used to set the proxy protocol version.  # noqa: E501

        :param proxy_protocol: The proxy_protocol of this TargetGroupTarget.  # noqa: E501
        :type proxy_protocol: str
        """
        allowed_values = ["none", "v1", "v2", "v2ssl"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and proxy_protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `proxy_protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(proxy_protocol, allowed_values)
            )

        self._proxy_protocol = proxy_protocol
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TargetGroupTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TargetGroupTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class PrivateCrossConnectProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'connectable_datacenters': 'list[ConnectableDatacenter]',

        'description': 'str',

        'name': 'str',

        'peers': 'list[Peer]',
    }

    attribute_map = {

        'connectable_datacenters': 'connectableDatacenters',

        'description': 'description',

        'name': 'name',

        'peers': 'peers',
    }

    def __init__(self, connectable_datacenters=None, description=None, name=None, peers=None, local_vars_configuration=None):  # noqa: E501
        """PrivateCrossConnectProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._connectable_datacenters = None
        self._description = None
        self._name = None
        self._peers = None
        self.discriminator = None

        if connectable_datacenters is not None:
            self.connectable_datacenters = connectable_datacenters
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if peers is not None:
            self.peers = peers


    @property
    def connectable_datacenters(self):
        """Gets the connectable_datacenters of this PrivateCrossConnectProperties.  # noqa: E501

        Read-Only attribute. Lists data centers that can be joined to this private Cross-Connect.  # noqa: E501

        :return: The connectable_datacenters of this PrivateCrossConnectProperties.  # noqa: E501
        :rtype: list[ConnectableDatacenter]
        """
        return self._connectable_datacenters

    @connectable_datacenters.setter
    def connectable_datacenters(self, connectable_datacenters):
        """Sets the connectable_datacenters of this PrivateCrossConnectProperties.

        Read-Only attribute. Lists data centers that can be joined to this private Cross-Connect.  # noqa: E501

        :param connectable_datacenters: The connectable_datacenters of this PrivateCrossConnectProperties.  # noqa: E501
        :type connectable_datacenters: list[ConnectableDatacenter]
        """

        self._connectable_datacenters = connectable_datacenters

    @property
    def description(self):
        """Gets the description of this PrivateCrossConnectProperties.  # noqa: E501

        Human-readable description.  # noqa: E501

        :return: The description of this PrivateCrossConnectProperties.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PrivateCrossConnectProperties.

        Human-readable description.  # noqa: E501

        :param description: The description of this PrivateCrossConnectProperties.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this PrivateCrossConnectProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this PrivateCrossConnectProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PrivateCrossConnectProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this PrivateCrossConnectProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def peers(self):
        """Gets the peers of this PrivateCrossConnectProperties.  # noqa: E501

        Read-Only attribute. Lists LAN's joined to this private Cross-Connect.  # noqa: E501

        :return: The peers of this PrivateCrossConnectProperties.  # noqa: E501
        :rtype: list[Peer]
        """
        return self._peers

    @peers.setter
    def peers(self, peers):
        """Sets the peers of this PrivateCrossConnectProperties.

        Read-Only attribute. Lists LAN's joined to this private Cross-Connect.  # noqa: E501

        :param peers: The peers of this PrivateCrossConnectProperties.  # noqa: E501
        :type peers: list[Peer]
        """

        self._peers = peers
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrivateCrossConnectProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrivateCrossConnectProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ServerProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'availability_zone': 'str',

        'boot_cdrom': 'ResourceReference',

        'boot_volume': 'ResourceReference',

        'cores': 'int',

        'cpu_family': 'str',

        'name': 'str',

        'ram': 'int',

        'template_uuid': 'str',

        'type': 'str',

        'vm_state': 'str',
    }

    attribute_map = {

        'availability_zone': 'availabilityZone',

        'boot_cdrom': 'bootCdrom',

        'boot_volume': 'bootVolume',

        'cores': 'cores',

        'cpu_family': 'cpuFamily',

        'name': 'name',

        'ram': 'ram',

        'template_uuid': 'templateUuid',

        'type': 'type',

        'vm_state': 'vmState',
    }

    def __init__(self, availability_zone=None, boot_cdrom=None, boot_volume=None, cores=None, cpu_family=None, name=None, ram=None, template_uuid=None, type=None, vm_state=None, local_vars_configuration=None):  # noqa: E501
        """ServerProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._availability_zone = None
        self._boot_cdrom = None
        self._boot_volume = None
        self._cores = None
        self._cpu_family = None
        self._name = None
        self._ram = None
        self._template_uuid = None
        self._type = None
        self._vm_state = None
        self.discriminator = None

        if availability_zone is not None:
            self.availability_zone = availability_zone
        if boot_cdrom is not None:
            self.boot_cdrom = boot_cdrom
        if boot_volume is not None:
            self.boot_volume = boot_volume
        if cores is not None:
            self.cores = cores
        if cpu_family is not None:
            self.cpu_family = cpu_family
        if name is not None:
            self.name = name
        if ram is not None:
            self.ram = ram
        if template_uuid is not None:
            self.template_uuid = template_uuid
        if type is not None:
            self.type = type
        if vm_state is not None:
            self.vm_state = vm_state


    @property
    def availability_zone(self):
        """Gets the availability_zone of this ServerProperties.  # noqa: E501

        The availability zone in which the server should be provisioned.  # noqa: E501

        :return: The availability_zone of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._availability_zone

    @availability_zone.setter
    def availability_zone(self, availability_zone):
        """Sets the availability_zone of this ServerProperties.

        The availability zone in which the server should be provisioned.  # noqa: E501

        :param availability_zone: The availability_zone of this ServerProperties.  # noqa: E501
        :type availability_zone: str
        """
        allowed_values = ["AUTO", "ZONE_1", "ZONE_2"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and availability_zone not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `availability_zone` ({0}), must be one of {1}"  # noqa: E501
                .format(availability_zone, allowed_values)
            )

        self._availability_zone = availability_zone

    @property
    def boot_cdrom(self):
        """Gets the boot_cdrom of this ServerProperties.  # noqa: E501


        :return: The boot_cdrom of this ServerProperties.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._boot_cdrom

    @boot_cdrom.setter
    def boot_cdrom(self, boot_cdrom):
        """Sets the boot_cdrom of this ServerProperties.


        :param boot_cdrom: The boot_cdrom of this ServerProperties.  # noqa: E501
        :type boot_cdrom: ResourceReference
        """

        self._boot_cdrom = boot_cdrom

    @property
    def boot_volume(self):
        """Gets the boot_volume of this ServerProperties.  # noqa: E501


        :return: The boot_volume of this ServerProperties.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._boot_volume

    @boot_volume.setter
    def boot_volume(self, boot_volume):
        """Sets the boot_volume of this ServerProperties.


        :param boot_volume: The boot_volume of this ServerProperties.  # noqa: E501
        :type boot_volume: ResourceReference
        """

        self._boot_volume = boot_volume

    @property
    def cores(self):
        """Gets the cores of this ServerProperties.  # noqa: E501

        The total number of cores for the enterprise server.  # noqa: E501

        :return: The cores of this ServerProperties.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this ServerProperties.

        The total number of cores for the enterprise server.  # noqa: E501

        :param cores: The cores of this ServerProperties.  # noqa: E501
        :type cores: int
        """

        self._cores = cores

    @property
    def cpu_family(self):
        """Gets the cpu_family of this ServerProperties.  # noqa: E501

        CPU architecture on which server gets provisioned; not all CPU architectures are available in all datacenter regions; available CPU architectures can be retrieved from the datacenter resource; must not be provided for CUBE servers.  # noqa: E501

        :return: The cpu_family of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._cpu_family

    @cpu_family.setter
    def cpu_family(self, cpu_family):
        """Sets the cpu_family of this ServerProperties.

        CPU architecture on which server gets provisioned; not all CPU architectures are available in all datacenter regions; available CPU architectures can be retrieved from the datacenter resource; must not be provided for CUBE servers.  # noqa: E501

        :param cpu_family: The cpu_family of this ServerProperties.  # noqa: E501
        :type cpu_family: str
        """

        self._cpu_family = cpu_family

    @property
    def name(self):
        """Gets the name of this ServerProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this ServerProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def ram(self):
        """Gets the ram of this ServerProperties.  # noqa: E501

        The memory size for the enterprise server in MB, such as 2048. Size must be specified in multiples of 256 MB with a minimum of 256 MB; however, if you set ramHotPlug to TRUE then you must use a minimum of 1024 MB. If you set the RAM size more than 240GB, then ramHotPlug will be set to FALSE and can not be set to TRUE unless RAM size not set to less than 240GB.  # noqa: E501

        :return: The ram of this ServerProperties.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this ServerProperties.

        The memory size for the enterprise server in MB, such as 2048. Size must be specified in multiples of 256 MB with a minimum of 256 MB; however, if you set ramHotPlug to TRUE then you must use a minimum of 1024 MB. If you set the RAM size more than 240GB, then ramHotPlug will be set to FALSE and can not be set to TRUE unless RAM size not set to less than 240GB.  # noqa: E501

        :param ram: The ram of this ServerProperties.  # noqa: E501
        :type ram: int
        """

        self._ram = ram

    @property
    def template_uuid(self):
        """Gets the template_uuid of this ServerProperties.  # noqa: E501

        The ID of the template for creating a CUBE server; the available templates for CUBE servers can be found on the templates resource.  # noqa: E501

        :return: The template_uuid of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._template_uuid

    @template_uuid.setter
    def template_uuid(self, template_uuid):
        """Sets the template_uuid of this ServerProperties.

        The ID of the template for creating a CUBE server; the available templates for CUBE servers can be found on the templates resource.  # noqa: E501

        :param template_uuid: The template_uuid of this ServerProperties.  # noqa: E501
        :type template_uuid: str
        """

        self._template_uuid = template_uuid

    @property
    def type(self):
        """Gets the type of this ServerProperties.  # noqa: E501

        Server type: CUBE or ENTERPRISE.  # noqa: E501

        :return: The type of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ServerProperties.

        Server type: CUBE or ENTERPRISE.  # noqa: E501

        :param type: The type of this ServerProperties.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def vm_state(self):
        """Gets the vm_state of this ServerProperties.  # noqa: E501

        Status of the virtual machine.  # noqa: E501

        :return: The vm_state of this ServerProperties.  # noqa: E501
        :rtype: str
        """
        return self._vm_state

    @vm_state.setter
    def vm_state(self, vm_state):
        """Sets the vm_state of this ServerProperties.

        Status of the virtual machine.  # noqa: E501

        :param vm_state: The vm_state of this ServerProperties.  # noqa: E501
        :type vm_state: str
        """
        allowed_values = ["NOSTATE", "RUNNING", "BLOCKED", "PAUSED", "SHUTDOWN", "SHUTOFF", "CRASHED", "SUSPENDED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and vm_state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `vm_state` ({0}), must be one of {1}"  # noqa: E501
                .format(vm_state, allowed_values)
            )

        self._vm_state = vm_state
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServerProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class UserPropertiesPost(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'active': 'bool',

        'administrator': 'bool',

        'email': 'str',

        'firstname': 'str',

        'force_sec_auth': 'bool',

        'lastname': 'str',

        'password': 'str',

        'sec_auth_active': 'bool',
    }

    attribute_map = {

        'active': 'active',

        'administrator': 'administrator',

        'email': 'email',

        'firstname': 'firstname',

        'force_sec_auth': 'forceSecAuth',

        'lastname': 'lastname',

        'password': 'password',

        'sec_auth_active': 'secAuthActive',
    }

    def __init__(self, active=None, administrator=None, email=None, firstname=None, force_sec_auth=None, lastname=None, password=None, sec_auth_active=None, local_vars_configuration=None):  # noqa: E501
        """UserPropertiesPost - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._administrator = None
        self._email = None
        self._firstname = None
        self._force_sec_auth = None
        self._lastname = None
        self._password = None
        self._sec_auth_active = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if administrator is not None:
            self.administrator = administrator
        if email is not None:
            self.email = email
        if firstname is not None:
            self.firstname = firstname
        if force_sec_auth is not None:
            self.force_sec_auth = force_sec_auth
        if lastname is not None:
            self.lastname = lastname
        if password is not None:
            self.password = password
        if sec_auth_active is not None:
            self.sec_auth_active = sec_auth_active


    @property
    def active(self):
        """Gets the active of this UserPropertiesPost.  # noqa: E501

        Indicates if the user is active.  # noqa: E501

        :return: The active of this UserPropertiesPost.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this UserPropertiesPost.

        Indicates if the user is active.  # noqa: E501

        :param active: The active of this UserPropertiesPost.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def administrator(self):
        """Gets the administrator of this UserPropertiesPost.  # noqa: E501

        Indicates if the user has admin rights.  # noqa: E501

        :return: The administrator of this UserPropertiesPost.  # noqa: E501
        :rtype: bool
        """
        return self._administrator

    @administrator.setter
    def administrator(self, administrator):
        """Sets the administrator of this UserPropertiesPost.

        Indicates if the user has admin rights.  # noqa: E501

        :param administrator: The administrator of this UserPropertiesPost.  # noqa: E501
        :type administrator: bool
        """

        self._administrator = administrator

    @property
    def email(self):
        """Gets the email of this UserPropertiesPost.  # noqa: E501

        The email address of the user.  # noqa: E501

        :return: The email of this UserPropertiesPost.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserPropertiesPost.

        The email address of the user.  # noqa: E501

        :param email: The email of this UserPropertiesPost.  # noqa: E501
        :type email: str
        """

        self._email = email

    @property
    def firstname(self):
        """Gets the firstname of this UserPropertiesPost.  # noqa: E501

        The first name of the user.  # noqa: E501

        :return: The firstname of this UserPropertiesPost.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this UserPropertiesPost.

        The first name of the user.  # noqa: E501

        :param firstname: The firstname of this UserPropertiesPost.  # noqa: E501
        :type firstname: str
        """

        self._firstname = firstname

    @property
    def force_sec_auth(self):
        """Gets the force_sec_auth of this UserPropertiesPost.  # noqa: E501

        Indicates if secure authentication should be forced on the user.  # noqa: E501

        :return: The force_sec_auth of this UserPropertiesPost.  # noqa: E501
        :rtype: bool
        """
        return self._force_sec_auth

    @force_sec_auth.setter
    def force_sec_auth(self, force_sec_auth):
        """Sets the force_sec_auth of this UserPropertiesPost.

        Indicates if secure authentication should be forced on the user.  # noqa: E501

        :param force_sec_auth: The force_sec_auth of this UserPropertiesPost.  # noqa: E501
        :type force_sec_auth: bool
        """

        self._force_sec_auth = force_sec_auth

    @property
    def lastname(self):
        """Gets the lastname of this UserPropertiesPost.  # noqa: E501

        The last name of the user.  # noqa: E501

        :return: The lastname of this UserPropertiesPost.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this UserPropertiesPost.

        The last name of the user.  # noqa: E501

        :param lastname: The lastname of this UserPropertiesPost.  # noqa: E501
        :type lastname: str
        """

        self._lastname = lastname

    @property
    def password(self):
        """Gets the password of this UserPropertiesPost.  # noqa: E501

        User password.  # noqa: E501

        :return: The password of this UserPropertiesPost.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UserPropertiesPost.

        User password.  # noqa: E501

        :param password: The password of this UserPropertiesPost.  # noqa: E501
        :type password: str
        """

        self._password = password

    @property
    def sec_auth_active(self):
        """Gets the sec_auth_active of this UserPropertiesPost.  # noqa: E501

        Indicates if secure authentication is active for the user.  # noqa: E501

        :return: The sec_auth_active of this UserPropertiesPost.  # noqa: E501
        :rtype: bool
        """
        return self._sec_auth_active

    @sec_auth_active.setter
    def sec_auth_active(self, sec_auth_active):
        """Sets the sec_auth_active of this UserPropertiesPost.

        Indicates if secure authentication is active for the user.  # noqa: E501

        :param sec_auth_active: The sec_auth_active of this UserPropertiesPost.  # noqa: E501
        :type sec_auth_active: bool
        """

        self._sec_auth_active = sec_auth_active
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserPropertiesPost):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserPropertiesPost):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class KubernetesClusterProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'api_subnet_allow_list': 'list[str]',

        'available_upgrade_versions': 'list[str]',

        'k8s_version': 'str',

        'location': 'str',

        'maintenance_window': 'KubernetesMaintenanceWindow',

        'name': 'str',

        'nat_gateway_ip': 'str',

        'node_subnet': 'str',

        'public': 'bool',

        's3_buckets': 'list[S3Bucket]',

        'viable_node_pool_versions': 'list[str]',
    }

    attribute_map = {

        'api_subnet_allow_list': 'apiSubnetAllowList',

        'available_upgrade_versions': 'availableUpgradeVersions',

        'k8s_version': 'k8sVersion',

        'location': 'location',

        'maintenance_window': 'maintenanceWindow',

        'name': 'name',

        'nat_gateway_ip': 'natGatewayIp',

        'node_subnet': 'nodeSubnet',

        'public': 'public',

        's3_buckets': 's3Buckets',

        'viable_node_pool_versions': 'viableNodePoolVersions',
    }

    def __init__(self, api_subnet_allow_list=None, available_upgrade_versions=None, k8s_version=None, location=None, maintenance_window=None, name=None, nat_gateway_ip=None, node_subnet=None, public=True, s3_buckets=None, viable_node_pool_versions=None, local_vars_configuration=None):  # noqa: E501
        """KubernetesClusterProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_subnet_allow_list = None
        self._available_upgrade_versions = None
        self._k8s_version = None
        self._location = None
        self._maintenance_window = None
        self._name = None
        self._nat_gateway_ip = None
        self._node_subnet = None
        self._public = None
        self._s3_buckets = None
        self._viable_node_pool_versions = None
        self.discriminator = None

        if api_subnet_allow_list is not None:
            self.api_subnet_allow_list = api_subnet_allow_list
        if available_upgrade_versions is not None:
            self.available_upgrade_versions = available_upgrade_versions
        if k8s_version is not None:
            self.k8s_version = k8s_version
        if location is not None:
            self.location = location
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window
        self.name = name
        if nat_gateway_ip is not None:
            self.nat_gateway_ip = nat_gateway_ip
        if node_subnet is not None:
            self.node_subnet = node_subnet
        if public is not None:
            self.public = public
        if s3_buckets is not None:
            self.s3_buckets = s3_buckets
        if viable_node_pool_versions is not None:
            self.viable_node_pool_versions = viable_node_pool_versions


    @property
    def api_subnet_allow_list(self):
        """Gets the api_subnet_allow_list of this KubernetesClusterProperties.  # noqa: E501

        Access to the K8s API server is restricted to these CIDRs. Traffic, internal to the cluster, is not affected by this restriction. If no allowlist is specified, access is not restricted. If an IP without subnet mask is provided, the default value is used: 32 for IPv4 and 128 for IPv6.  # noqa: E501

        :return: The api_subnet_allow_list of this KubernetesClusterProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._api_subnet_allow_list

    @api_subnet_allow_list.setter
    def api_subnet_allow_list(self, api_subnet_allow_list):
        """Sets the api_subnet_allow_list of this KubernetesClusterProperties.

        Access to the K8s API server is restricted to these CIDRs. Traffic, internal to the cluster, is not affected by this restriction. If no allowlist is specified, access is not restricted. If an IP without subnet mask is provided, the default value is used: 32 for IPv4 and 128 for IPv6.  # noqa: E501

        :param api_subnet_allow_list: The api_subnet_allow_list of this KubernetesClusterProperties.  # noqa: E501
        :type api_subnet_allow_list: list[str]
        """

        self._api_subnet_allow_list = api_subnet_allow_list

    @property
    def available_upgrade_versions(self):
        """Gets the available_upgrade_versions of this KubernetesClusterProperties.  # noqa: E501

        List of available versions for upgrading the cluster  # noqa: E501

        :return: The available_upgrade_versions of this KubernetesClusterProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._available_upgrade_versions

    @available_upgrade_versions.setter
    def available_upgrade_versions(self, available_upgrade_versions):
        """Sets the available_upgrade_versions of this KubernetesClusterProperties.

        List of available versions for upgrading the cluster  # noqa: E501

        :param available_upgrade_versions: The available_upgrade_versions of this KubernetesClusterProperties.  # noqa: E501
        :type available_upgrade_versions: list[str]
        """

        self._available_upgrade_versions = available_upgrade_versions

    @property
    def k8s_version(self):
        """Gets the k8s_version of this KubernetesClusterProperties.  # noqa: E501

        The Kubernetes version the cluster is running. This imposes restrictions on what Kubernetes versions can be run in a cluster's nodepools. Additionally, not all Kubernetes versions are viable upgrade targets for all prior versions.  # noqa: E501

        :return: The k8s_version of this KubernetesClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._k8s_version

    @k8s_version.setter
    def k8s_version(self, k8s_version):
        """Sets the k8s_version of this KubernetesClusterProperties.

        The Kubernetes version the cluster is running. This imposes restrictions on what Kubernetes versions can be run in a cluster's nodepools. Additionally, not all Kubernetes versions are viable upgrade targets for all prior versions.  # noqa: E501

        :param k8s_version: The k8s_version of this KubernetesClusterProperties.  # noqa: E501
        :type k8s_version: str
        """

        self._k8s_version = k8s_version

    @property
    def location(self):
        """Gets the location of this KubernetesClusterProperties.  # noqa: E501

        The location of the cluster if the cluster is private. This property is immutable. The location must be enabled for your contract or you must have a Datacenter within that location. This attribute is mandatory if the cluster is private.  # noqa: E501

        :return: The location of this KubernetesClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this KubernetesClusterProperties.

        The location of the cluster if the cluster is private. This property is immutable. The location must be enabled for your contract or you must have a Datacenter within that location. This attribute is mandatory if the cluster is private.  # noqa: E501

        :param location: The location of this KubernetesClusterProperties.  # noqa: E501
        :type location: str
        """

        self._location = location

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this KubernetesClusterProperties.  # noqa: E501


        :return: The maintenance_window of this KubernetesClusterProperties.  # noqa: E501
        :rtype: KubernetesMaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this KubernetesClusterProperties.


        :param maintenance_window: The maintenance_window of this KubernetesClusterProperties.  # noqa: E501
        :type maintenance_window: KubernetesMaintenanceWindow
        """

        self._maintenance_window = maintenance_window

    @property
    def name(self):
        """Gets the name of this KubernetesClusterProperties.  # noqa: E501

        A Kubernetes cluster name. Valid Kubernetes cluster name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :return: The name of this KubernetesClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesClusterProperties.

        A Kubernetes cluster name. Valid Kubernetes cluster name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :param name: The name of this KubernetesClusterProperties.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def nat_gateway_ip(self):
        """Gets the nat_gateway_ip of this KubernetesClusterProperties.  # noqa: E501

        The nat gateway IP of the cluster if the cluster is private. This property is immutable. Must be a reserved IP in the same location as the cluster's location. This attribute is mandatory if the cluster is private.  # noqa: E501

        :return: The nat_gateway_ip of this KubernetesClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._nat_gateway_ip

    @nat_gateway_ip.setter
    def nat_gateway_ip(self, nat_gateway_ip):
        """Sets the nat_gateway_ip of this KubernetesClusterProperties.

        The nat gateway IP of the cluster if the cluster is private. This property is immutable. Must be a reserved IP in the same location as the cluster's location. This attribute is mandatory if the cluster is private.  # noqa: E501

        :param nat_gateway_ip: The nat_gateway_ip of this KubernetesClusterProperties.  # noqa: E501
        :type nat_gateway_ip: str
        """

        self._nat_gateway_ip = nat_gateway_ip

    @property
    def node_subnet(self):
        """Gets the node_subnet of this KubernetesClusterProperties.  # noqa: E501

        The node subnet of the cluster, if the cluster is private. This property is optional and immutable. Must be a valid CIDR notation for an IPv4 network prefix of 16 bits length.  # noqa: E501

        :return: The node_subnet of this KubernetesClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._node_subnet

    @node_subnet.setter
    def node_subnet(self, node_subnet):
        """Sets the node_subnet of this KubernetesClusterProperties.

        The node subnet of the cluster, if the cluster is private. This property is optional and immutable. Must be a valid CIDR notation for an IPv4 network prefix of 16 bits length.  # noqa: E501

        :param node_subnet: The node_subnet of this KubernetesClusterProperties.  # noqa: E501
        :type node_subnet: str
        """

        self._node_subnet = node_subnet

    @property
    def public(self):
        """Gets the public of this KubernetesClusterProperties.  # noqa: E501

        The indicator if the cluster is public or private. Be aware that setting it to false is currently in beta phase.  # noqa: E501

        :return: The public of this KubernetesClusterProperties.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this KubernetesClusterProperties.

        The indicator if the cluster is public or private. Be aware that setting it to false is currently in beta phase.  # noqa: E501

        :param public: The public of this KubernetesClusterProperties.  # noqa: E501
        :type public: bool
        """

        self._public = public

    @property
    def s3_buckets(self):
        """Gets the s3_buckets of this KubernetesClusterProperties.  # noqa: E501

        List of S3 bucket configured for K8s usage. For now it contains only an S3 bucket used to store K8s API audit logs  # noqa: E501

        :return: The s3_buckets of this KubernetesClusterProperties.  # noqa: E501
        :rtype: list[S3Bucket]
        """
        return self._s3_buckets

    @s3_buckets.setter
    def s3_buckets(self, s3_buckets):
        """Sets the s3_buckets of this KubernetesClusterProperties.

        List of S3 bucket configured for K8s usage. For now it contains only an S3 bucket used to store K8s API audit logs  # noqa: E501

        :param s3_buckets: The s3_buckets of this KubernetesClusterProperties.  # noqa: E501
        :type s3_buckets: list[S3Bucket]
        """

        self._s3_buckets = s3_buckets

    @property
    def viable_node_pool_versions(self):
        """Gets the viable_node_pool_versions of this KubernetesClusterProperties.  # noqa: E501

        List of versions that may be used for node pools under this cluster  # noqa: E501

        :return: The viable_node_pool_versions of this KubernetesClusterProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._viable_node_pool_versions

    @viable_node_pool_versions.setter
    def viable_node_pool_versions(self, viable_node_pool_versions):
        """Sets the viable_node_pool_versions of this KubernetesClusterProperties.

        List of versions that may be used for node pools under this cluster  # noqa: E501

        :param viable_node_pool_versions: The viable_node_pool_versions of this KubernetesClusterProperties.  # noqa: E501
        :type viable_node_pool_versions: list[str]
        """

        self._viable_node_pool_versions = viable_node_pool_versions
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesClusterProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesClusterProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from ionoscloud.models.application_load_balancer import ApplicationLoadBalancer
from ionoscloud.models.application_load_balancer_entities import ApplicationLoadBalancerEntities
from ionoscloud.models.application_load_balancer_forwarding_rule import ApplicationLoadBalancerForwardingRule
from ionoscloud.models.application_load_balancer_forwarding_rule_properties import ApplicationLoadBalancerForwardingRuleProperties
from ionoscloud.models.application_load_balancer_forwarding_rule_put import ApplicationLoadBalancerForwardingRulePut
from ionoscloud.models.application_load_balancer_forwarding_rules import ApplicationLoadBalancerForwardingRules
from ionoscloud.models.application_load_balancer_http_rule import ApplicationLoadBalancerHttpRule
from ionoscloud.models.application_load_balancer_http_rule_condition import ApplicationLoadBalancerHttpRuleCondition
from ionoscloud.models.application_load_balancer_properties import ApplicationLoadBalancerProperties
from ionoscloud.models.application_load_balancer_put import ApplicationLoadBalancerPut
from ionoscloud.models.application_load_balancers import ApplicationLoadBalancers
from ionoscloud.models.attached_volumes import AttachedVolumes
from ionoscloud.models.backup_unit import BackupUnit
from ionoscloud.models.backup_unit_properties import BackupUnitProperties
from ionoscloud.models.backup_unit_sso import BackupUnitSSO
from ionoscloud.models.backup_units import BackupUnits
from ionoscloud.models.balanced_nics import BalancedNics
from ionoscloud.models.cdroms import Cdroms
from ionoscloud.models.connectable_datacenter import ConnectableDatacenter
from ionoscloud.models.contract import Contract
from ionoscloud.models.contract_properties import ContractProperties
from ionoscloud.models.contracts import Contracts
from ionoscloud.models.cpu_architecture_properties import CpuArchitectureProperties
from ionoscloud.models.data_center_entities import DataCenterEntities
from ionoscloud.models.datacenter import Datacenter
from ionoscloud.models.datacenter_element_metadata import DatacenterElementMetadata
from ionoscloud.models.datacenter_properties import DatacenterProperties
from ionoscloud.models.datacenters import Datacenters
from ionoscloud.models.error import Error
from ionoscloud.models.error_message import ErrorMessage
from ionoscloud.models.firewall_rule import FirewallRule
from ionoscloud.models.firewall_rules import FirewallRules
from ionoscloud.models.firewallrule_properties import FirewallruleProperties
from ionoscloud.models.flow_log import FlowLog
from ionoscloud.models.flow_log_properties import FlowLogProperties
from ionoscloud.models.flow_log_put import FlowLogPut
from ionoscloud.models.flow_logs import FlowLogs
from ionoscloud.models.group import Group
from ionoscloud.models.group_entities import GroupEntities
from ionoscloud.models.group_members import GroupMembers
from ionoscloud.models.group_properties import GroupProperties
from ionoscloud.models.group_share import GroupShare
from ionoscloud.models.group_share_properties import GroupShareProperties
from ionoscloud.models.group_shares import GroupShares
from ionoscloud.models.group_users import GroupUsers
from ionoscloud.models.groups import Groups
from ionoscloud.models.ip_failover import IPFailover
from ionoscloud.models.image import Image
from ionoscloud.models.image_properties import ImageProperties
from ionoscloud.models.images import Images
from ionoscloud.models.info import Info
from ionoscloud.models.ip_block import IpBlock
from ionoscloud.models.ip_block_properties import IpBlockProperties
from ionoscloud.models.ip_blocks import IpBlocks
from ionoscloud.models.ip_consumer import IpConsumer
from ionoscloud.models.kubernetes_auto_scaling import KubernetesAutoScaling
from ionoscloud.models.kubernetes_cluster import KubernetesCluster
from ionoscloud.models.kubernetes_cluster_entities import KubernetesClusterEntities
from ionoscloud.models.kubernetes_cluster_for_post import KubernetesClusterForPost
from ionoscloud.models.kubernetes_cluster_for_put import KubernetesClusterForPut
from ionoscloud.models.kubernetes_cluster_properties import KubernetesClusterProperties
from ionoscloud.models.kubernetes_cluster_properties_for_post import KubernetesClusterPropertiesForPost
from ionoscloud.models.kubernetes_cluster_properties_for_put import KubernetesClusterPropertiesForPut
from ionoscloud.models.kubernetes_clusters import KubernetesClusters
from ionoscloud.models.kubernetes_maintenance_window import KubernetesMaintenanceWindow
from ionoscloud.models.kubernetes_node import KubernetesNode
from ionoscloud.models.kubernetes_node_metadata import KubernetesNodeMetadata
from ionoscloud.models.kubernetes_node_pool import KubernetesNodePool
from ionoscloud.models.kubernetes_node_pool_for_post import KubernetesNodePoolForPost
from ionoscloud.models.kubernetes_node_pool_for_put import KubernetesNodePoolForPut
from ionoscloud.models.kubernetes_node_pool_lan import KubernetesNodePoolLan
from ionoscloud.models.kubernetes_node_pool_lan_routes import KubernetesNodePoolLanRoutes
from ionoscloud.models.kubernetes_node_pool_properties import KubernetesNodePoolProperties
from ionoscloud.models.kubernetes_node_pool_properties_for_post import KubernetesNodePoolPropertiesForPost
from ionoscloud.models.kubernetes_node_pool_properties_for_put import KubernetesNodePoolPropertiesForPut
from ionoscloud.models.kubernetes_node_pools import KubernetesNodePools
from ionoscloud.models.kubernetes_node_properties import KubernetesNodeProperties
from ionoscloud.models.kubernetes_nodes import KubernetesNodes
from ionoscloud.models.label import Label
from ionoscloud.models.label_properties import LabelProperties
from ionoscloud.models.label_resource import LabelResource
from ionoscloud.models.label_resource_properties import LabelResourceProperties
from ionoscloud.models.label_resources import LabelResources
from ionoscloud.models.labels import Labels
from ionoscloud.models.lan import Lan
from ionoscloud.models.lan_entities import LanEntities
from ionoscloud.models.lan_nics import LanNics
from ionoscloud.models.lan_post import LanPost
from ionoscloud.models.lan_properties import LanProperties
from ionoscloud.models.lan_properties_post import LanPropertiesPost
from ionoscloud.models.lans import Lans
from ionoscloud.models.loadbalancer import Loadbalancer
from ionoscloud.models.loadbalancer_entities import LoadbalancerEntities
from ionoscloud.models.loadbalancer_properties import LoadbalancerProperties
from ionoscloud.models.loadbalancers import Loadbalancers
from ionoscloud.models.location import Location
from ionoscloud.models.location_properties import LocationProperties
from ionoscloud.models.locations import Locations
from ionoscloud.models.nat_gateway import NatGateway
from ionoscloud.models.nat_gateway_entities import NatGatewayEntities
from ionoscloud.models.nat_gateway_lan_properties import NatGatewayLanProperties
from ionoscloud.models.nat_gateway_properties import NatGatewayProperties
from ionoscloud.models.nat_gateway_put import NatGatewayPut
from ionoscloud.models.nat_gateway_rule import NatGatewayRule
from ionoscloud.models.nat_gateway_rule_properties import NatGatewayRuleProperties
from ionoscloud.models.nat_gateway_rule_protocol import NatGatewayRuleProtocol
from ionoscloud.models.nat_gateway_rule_put import NatGatewayRulePut
from ionoscloud.models.nat_gateway_rule_type import NatGatewayRuleType
from ionoscloud.models.nat_gateway_rules import NatGatewayRules
from ionoscloud.models.nat_gateways import NatGateways
from ionoscloud.models.network_load_balancer import NetworkLoadBalancer
from ionoscloud.models.network_load_balancer_entities import NetworkLoadBalancerEntities
from ionoscloud.models.network_load_balancer_forwarding_rule import NetworkLoadBalancerForwardingRule
from ionoscloud.models.network_load_balancer_forwarding_rule_health_check import NetworkLoadBalancerForwardingRuleHealthCheck
from ionoscloud.models.network_load_balancer_forwarding_rule_properties import NetworkLoadBalancerForwardingRuleProperties
from ionoscloud.models.network_load_balancer_forwarding_rule_put import NetworkLoadBalancerForwardingRulePut
from ionoscloud.models.network_load_balancer_forwarding_rule_target import NetworkLoadBalancerForwardingRuleTarget
from ionoscloud.models.network_load_balancer_forwarding_rule_target_health_check import NetworkLoadBalancerForwardingRuleTargetHealthCheck
from ionoscloud.models.network_load_balancer_forwarding_rules import NetworkLoadBalancerForwardingRules
from ionoscloud.models.network_load_balancer_properties import NetworkLoadBalancerProperties
from ionoscloud.models.network_load_balancer_put import NetworkLoadBalancerPut
from ionoscloud.models.network_load_balancers import NetworkLoadBalancers
from ionoscloud.models.nic import Nic
from ionoscloud.models.nic_entities import NicEntities
from ionoscloud.models.nic_properties import NicProperties
from ionoscloud.models.nic_put import NicPut
from ionoscloud.models.nics import Nics
from ionoscloud.models.no_state_meta_data import NoStateMetaData
from ionoscloud.models.pagination_links import PaginationLinks
from ionoscloud.models.peer import Peer
from ionoscloud.models.private_cross_connect import PrivateCrossConnect
from ionoscloud.models.private_cross_connect_properties import PrivateCrossConnectProperties
from ionoscloud.models.private_cross_connects import PrivateCrossConnects
from ionoscloud.models.remote_console_url import RemoteConsoleUrl
from ionoscloud.models.request import Request
from ionoscloud.models.request_metadata import RequestMetadata
from ionoscloud.models.request_properties import RequestProperties
from ionoscloud.models.request_status import RequestStatus
from ionoscloud.models.request_status_metadata import RequestStatusMetadata
from ionoscloud.models.request_target import RequestTarget
from ionoscloud.models.requests import Requests
from ionoscloud.models.resource import Resource
from ionoscloud.models.resource_entities import ResourceEntities
from ionoscloud.models.resource_groups import ResourceGroups
from ionoscloud.models.resource_limits import ResourceLimits
from ionoscloud.models.resource_properties import ResourceProperties
from ionoscloud.models.resource_reference import ResourceReference
from ionoscloud.models.resources import Resources
from ionoscloud.models.resources_users import ResourcesUsers
from ionoscloud.models.s3_bucket import S3Bucket
from ionoscloud.models.s3_key import S3Key
from ionoscloud.models.s3_key_metadata import S3KeyMetadata
from ionoscloud.models.s3_key_properties import S3KeyProperties
from ionoscloud.models.s3_keys import S3Keys
from ionoscloud.models.s3_object_storage_sso import S3ObjectStorageSSO
from ionoscloud.models.server import Server
from ionoscloud.models.server_entities import ServerEntities
from ionoscloud.models.server_properties import ServerProperties
from ionoscloud.models.servers import Servers
from ionoscloud.models.snapshot import Snapshot
from ionoscloud.models.snapshot_properties import SnapshotProperties
from ionoscloud.models.snapshots import Snapshots
from ionoscloud.models.target_group import TargetGroup
from ionoscloud.models.target_group_health_check import TargetGroupHealthCheck
from ionoscloud.models.target_group_http_health_check import TargetGroupHttpHealthCheck
from ionoscloud.models.target_group_properties import TargetGroupProperties
from ionoscloud.models.target_group_put import TargetGroupPut
from ionoscloud.models.target_group_target import TargetGroupTarget
from ionoscloud.models.target_groups import TargetGroups
from ionoscloud.models.target_port_range import TargetPortRange
from ionoscloud.models.template import Template
from ionoscloud.models.template_properties import TemplateProperties
from ionoscloud.models.templates import Templates
from ionoscloud.models.token import Token
from ionoscloud.models.type import Type
from ionoscloud.models.user import User
from ionoscloud.models.user_metadata import UserMetadata
from ionoscloud.models.user_post import UserPost
from ionoscloud.models.user_properties import UserProperties
from ionoscloud.models.user_properties_post import UserPropertiesPost
from ionoscloud.models.user_properties_put import UserPropertiesPut
from ionoscloud.models.user_put import UserPut
from ionoscloud.models.users import Users
from ionoscloud.models.users_entities import UsersEntities
from ionoscloud.models.volume import Volume
from ionoscloud.models.volume_properties import VolumeProperties
from ionoscloud.models.volumes import Volumes



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class KubernetesClusterPropertiesForPut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'api_subnet_allow_list': 'list[str]',

        'k8s_version': 'str',

        'maintenance_window': 'KubernetesMaintenanceWindow',

        'name': 'str',

        's3_buckets': 'list[S3Bucket]',
    }

    attribute_map = {

        'api_subnet_allow_list': 'apiSubnetAllowList',

        'k8s_version': 'k8sVersion',

        'maintenance_window': 'maintenanceWindow',

        'name': 'name',

        's3_buckets': 's3Buckets',
    }

    def __init__(self, api_subnet_allow_list=None, k8s_version=None, maintenance_window=None, name=None, s3_buckets=None, local_vars_configuration=None):  # noqa: E501
        """KubernetesClusterPropertiesForPut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_subnet_allow_list = None
        self._k8s_version = None
        self._maintenance_window = None
        self._name = None
        self._s3_buckets = None
        self.discriminator = None

        if api_subnet_allow_list is not None:
            self.api_subnet_allow_list = api_subnet_allow_list
        if k8s_version is not None:
            self.k8s_version = k8s_version
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window
        self.name = name
        if s3_buckets is not None:
            self.s3_buckets = s3_buckets


    @property
    def api_subnet_allow_list(self):
        """Gets the api_subnet_allow_list of this KubernetesClusterPropertiesForPut.  # noqa: E501

        Access to the K8s API server is restricted to these CIDRs. Intra-cluster traffic is not affected by this restriction. If no AllowList is specified, access is not limited. If an IP is specified without a subnet mask, the default value is 32 for IPv4 and 128 for IPv6.  # noqa: E501

        :return: The api_subnet_allow_list of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :rtype: list[str]
        """
        return self._api_subnet_allow_list

    @api_subnet_allow_list.setter
    def api_subnet_allow_list(self, api_subnet_allow_list):
        """Sets the api_subnet_allow_list of this KubernetesClusterPropertiesForPut.

        Access to the K8s API server is restricted to these CIDRs. Intra-cluster traffic is not affected by this restriction. If no AllowList is specified, access is not limited. If an IP is specified without a subnet mask, the default value is 32 for IPv4 and 128 for IPv6.  # noqa: E501

        :param api_subnet_allow_list: The api_subnet_allow_list of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :type api_subnet_allow_list: list[str]
        """

        self._api_subnet_allow_list = api_subnet_allow_list

    @property
    def k8s_version(self):
        """Gets the k8s_version of this KubernetesClusterPropertiesForPut.  # noqa: E501

        The Kubernetes version that the cluster is running. This limits which Kubernetes versions can run in a cluster's node pools. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :return: The k8s_version of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :rtype: str
        """
        return self._k8s_version

    @k8s_version.setter
    def k8s_version(self, k8s_version):
        """Sets the k8s_version of this KubernetesClusterPropertiesForPut.

        The Kubernetes version that the cluster is running. This limits which Kubernetes versions can run in a cluster's node pools. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :param k8s_version: The k8s_version of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :type k8s_version: str
        """

        self._k8s_version = k8s_version

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this KubernetesClusterPropertiesForPut.  # noqa: E501


        :return: The maintenance_window of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :rtype: KubernetesMaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this KubernetesClusterPropertiesForPut.


        :param maintenance_window: The maintenance_window of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :type maintenance_window: KubernetesMaintenanceWindow
        """

        self._maintenance_window = maintenance_window

    @property
    def name(self):
        """Gets the name of this KubernetesClusterPropertiesForPut.  # noqa: E501

        A Kubernetes cluster name. Valid Kubernetes cluster name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :return: The name of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesClusterPropertiesForPut.

        A Kubernetes cluster name. Valid Kubernetes cluster name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :param name: The name of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def s3_buckets(self):
        """Gets the s3_buckets of this KubernetesClusterPropertiesForPut.  # noqa: E501

        List of S3 buckets configured for K8s usage. At the moment, it contains only one S3 bucket that is used to store K8s API audit logs.  # noqa: E501

        :return: The s3_buckets of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :rtype: list[S3Bucket]
        """
        return self._s3_buckets

    @s3_buckets.setter
    def s3_buckets(self, s3_buckets):
        """Sets the s3_buckets of this KubernetesClusterPropertiesForPut.

        List of S3 buckets configured for K8s usage. At the moment, it contains only one S3 bucket that is used to store K8s API audit logs.  # noqa: E501

        :param s3_buckets: The s3_buckets of this KubernetesClusterPropertiesForPut.  # noqa: E501
        :type s3_buckets: list[S3Bucket]
        """

        self._s3_buckets = s3_buckets
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesClusterPropertiesForPut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesClusterPropertiesForPut):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class NicProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'device_number': 'int',

        'dhcp': 'bool',

        'dhcpv6': 'bool',

        'firewall_active': 'bool',

        'firewall_type': 'str',

        'ips': 'list[str]',

        'ipv6_cidr_block': 'str',

        'ipv6_ips': 'list[str]',

        'lan': 'int',

        'mac': 'str',

        'name': 'str',

        'pci_slot': 'int',
    }

    attribute_map = {

        'device_number': 'deviceNumber',

        'dhcp': 'dhcp',

        'dhcpv6': 'dhcpv6',

        'firewall_active': 'firewallActive',

        'firewall_type': 'firewallType',

        'ips': 'ips',

        'ipv6_cidr_block': 'ipv6CidrBlock',

        'ipv6_ips': 'ipv6Ips',

        'lan': 'lan',

        'mac': 'mac',

        'name': 'name',

        'pci_slot': 'pciSlot',
    }

    def __init__(self, device_number=None, dhcp=True, dhcpv6=None, firewall_active=None, firewall_type=None, ips=None, ipv6_cidr_block=None, ipv6_ips=None, lan=None, mac=None, name=None, pci_slot=None, local_vars_configuration=None):  # noqa: E501
        """NicProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_number = None
        self._dhcp = None
        self._dhcpv6 = None
        self._firewall_active = None
        self._firewall_type = None
        self._ips = None
        self._ipv6_cidr_block = None
        self._ipv6_ips = None
        self._lan = None
        self._mac = None
        self._name = None
        self._pci_slot = None
        self.discriminator = None

        if device_number is not None:
            self.device_number = device_number
        if dhcp is not None:
            self.dhcp = dhcp
        self.dhcpv6 = dhcpv6
        if firewall_active is not None:
            self.firewall_active = firewall_active
        if firewall_type is not None:
            self.firewall_type = firewall_type
        self.ips = ips
        self.ipv6_cidr_block = ipv6_cidr_block
        self.ipv6_ips = ipv6_ips
        self.lan = lan
        if mac is not None:
            self.mac = mac
        if name is not None:
            self.name = name
        if pci_slot is not None:
            self.pci_slot = pci_slot


    @property
    def device_number(self):
        """Gets the device_number of this NicProperties.  # noqa: E501

        The Logical Unit Number (LUN) of the storage volume. Null if this NIC was created using Cloud API and no DCD changes were performed on the Datacenter.  # noqa: E501

        :return: The device_number of this NicProperties.  # noqa: E501
        :rtype: int
        """
        return self._device_number

    @device_number.setter
    def device_number(self, device_number):
        """Sets the device_number of this NicProperties.

        The Logical Unit Number (LUN) of the storage volume. Null if this NIC was created using Cloud API and no DCD changes were performed on the Datacenter.  # noqa: E501

        :param device_number: The device_number of this NicProperties.  # noqa: E501
        :type device_number: int
        """

        self._device_number = device_number

    @property
    def dhcp(self):
        """Gets the dhcp of this NicProperties.  # noqa: E501

        Indicates if the NIC will reserve an IP using DHCP.  # noqa: E501

        :return: The dhcp of this NicProperties.  # noqa: E501
        :rtype: bool
        """
        return self._dhcp

    @dhcp.setter
    def dhcp(self, dhcp):
        """Sets the dhcp of this NicProperties.

        Indicates if the NIC will reserve an IP using DHCP.  # noqa: E501

        :param dhcp: The dhcp of this NicProperties.  # noqa: E501
        :type dhcp: bool
        """

        self._dhcp = dhcp

    @property
    def dhcpv6(self):
        """Gets the dhcpv6 of this NicProperties.  # noqa: E501

        Indicates if the NIC will receive an IPv6 using DHCP. It can be set to 'true' or 'false' only if this NIC is connected to an IPv6 enabled LAN.  # noqa: E501

        :return: The dhcpv6 of this NicProperties.  # noqa: E501
        :rtype: bool
        """
        return self._dhcpv6

    @dhcpv6.setter
    def dhcpv6(self, dhcpv6):
        """Sets the dhcpv6 of this NicProperties.

        Indicates if the NIC will receive an IPv6 using DHCP. It can be set to 'true' or 'false' only if this NIC is connected to an IPv6 enabled LAN.  # noqa: E501

        :param dhcpv6: The dhcpv6 of this NicProperties.  # noqa: E501
        :type dhcpv6: bool
        """

        self._dhcpv6 = dhcpv6

    @property
    def firewall_active(self):
        """Gets the firewall_active of this NicProperties.  # noqa: E501

        Activate or deactivate the firewall. By default, an active firewall without any defined rules will block all incoming network traffic except for the firewall rules that explicitly allows certain protocols, IP addresses and ports.  # noqa: E501

        :return: The firewall_active of this NicProperties.  # noqa: E501
        :rtype: bool
        """
        return self._firewall_active

    @firewall_active.setter
    def firewall_active(self, firewall_active):
        """Sets the firewall_active of this NicProperties.

        Activate or deactivate the firewall. By default, an active firewall without any defined rules will block all incoming network traffic except for the firewall rules that explicitly allows certain protocols, IP addresses and ports.  # noqa: E501

        :param firewall_active: The firewall_active of this NicProperties.  # noqa: E501
        :type firewall_active: bool
        """

        self._firewall_active = firewall_active

    @property
    def firewall_type(self):
        """Gets the firewall_type of this NicProperties.  # noqa: E501

        The type of firewall rules that will be allowed on the NIC. If not specified, the default INGRESS value is used.  # noqa: E501

        :return: The firewall_type of this NicProperties.  # noqa: E501
        :rtype: str
        """
        return self._firewall_type

    @firewall_type.setter
    def firewall_type(self, firewall_type):
        """Sets the firewall_type of this NicProperties.

        The type of firewall rules that will be allowed on the NIC. If not specified, the default INGRESS value is used.  # noqa: E501

        :param firewall_type: The firewall_type of this NicProperties.  # noqa: E501
        :type firewall_type: str
        """
        allowed_values = ["INGRESS", "EGRESS", "BIDIRECTIONAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and firewall_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `firewall_type` ({0}), must be one of {1}"  # noqa: E501
                .format(firewall_type, allowed_values)
            )

        self._firewall_type = firewall_type

    @property
    def ips(self):
        """Gets the ips of this NicProperties.  # noqa: E501

        Collection of IP addresses, assigned to the NIC. Explicitly assigned public IPs need to come from reserved IP blocks. Passing value null or empty array will assign an IP address automatically.  # noqa: E501

        :return: The ips of this NicProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this NicProperties.

        Collection of IP addresses, assigned to the NIC. Explicitly assigned public IPs need to come from reserved IP blocks. Passing value null or empty array will assign an IP address automatically.  # noqa: E501

        :param ips: The ips of this NicProperties.  # noqa: E501
        :type ips: list[str]
        """

        self._ips = ips

    @property
    def ipv6_cidr_block(self):
        """Gets the ipv6_cidr_block of this NicProperties.  # noqa: E501

        If this NIC is connected to an IPv6 enabled LAN then this property contains the /80 IPv6 CIDR block of the NIC. If you leave this property 'null' when adding a NIC to an IPv6-enabled LAN, then an IPv6 CIDR block will automatically be assigned to the NIC, but you can also specify an /80 IPv6 CIDR block for the NIC on your own, which must be inside the /64 IPv6 CIDR block of the LAN and unique. This value can only be set, if the LAN already has an IPv6 CIDR block assigned. An IPv6-enabled LAN is limited to a maximum of 65,536 NICs.  # noqa: E501

        :return: The ipv6_cidr_block of this NicProperties.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """Sets the ipv6_cidr_block of this NicProperties.

        If this NIC is connected to an IPv6 enabled LAN then this property contains the /80 IPv6 CIDR block of the NIC. If you leave this property 'null' when adding a NIC to an IPv6-enabled LAN, then an IPv6 CIDR block will automatically be assigned to the NIC, but you can also specify an /80 IPv6 CIDR block for the NIC on your own, which must be inside the /64 IPv6 CIDR block of the LAN and unique. This value can only be set, if the LAN already has an IPv6 CIDR block assigned. An IPv6-enabled LAN is limited to a maximum of 65,536 NICs.  # noqa: E501

        :param ipv6_cidr_block: The ipv6_cidr_block of this NicProperties.  # noqa: E501
        :type ipv6_cidr_block: str
        """

        self._ipv6_cidr_block = ipv6_cidr_block

    @property
    def ipv6_ips(self):
        """Gets the ipv6_ips of this NicProperties.  # noqa: E501

        If this NIC is connected to an IPv6 enabled LAN then this property contains the IPv6 IP addresses of the NIC. The maximum number of IPv6 IP addresses per NIC is 50, if you need more, contact support. If you leave this property 'null' when adding a NIC, when changing the NIC's IPv6 CIDR block, when changing the LAN's IPv6 CIDR block or when moving the NIC to a different IPv6 enabled LAN, then we will automatically assign the same number of IPv6 addresses which you had before from the NICs new CIDR block. If you leave this property 'null' while not changing the CIDR block, the IPv6 IP addresses won't be changed either. You can also provide your own self choosen IPv6 addresses, which then must be inside the IPv6 CIDR block of this NIC.  # noqa: E501

        :return: The ipv6_ips of this NicProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._ipv6_ips

    @ipv6_ips.setter
    def ipv6_ips(self, ipv6_ips):
        """Sets the ipv6_ips of this NicProperties.

        If this NIC is connected to an IPv6 enabled LAN then this property contains the IPv6 IP addresses of the NIC. The maximum number of IPv6 IP addresses per NIC is 50, if you need more, contact support. If you leave this property 'null' when adding a NIC, when changing the NIC's IPv6 CIDR block, when changing the LAN's IPv6 CIDR block or when moving the NIC to a different IPv6 enabled LAN, then we will automatically assign the same number of IPv6 addresses which you had before from the NICs new CIDR block. If you leave this property 'null' while not changing the CIDR block, the IPv6 IP addresses won't be changed either. You can also provide your own self choosen IPv6 addresses, which then must be inside the IPv6 CIDR block of this NIC.  # noqa: E501

        :param ipv6_ips: The ipv6_ips of this NicProperties.  # noqa: E501
        :type ipv6_ips: list[str]
        """

        self._ipv6_ips = ipv6_ips

    @property
    def lan(self):
        """Gets the lan of this NicProperties.  # noqa: E501

        The LAN ID the NIC will be on. If the LAN ID does not exist, it will be implicitly created.  # noqa: E501

        :return: The lan of this NicProperties.  # noqa: E501
        :rtype: int
        """
        return self._lan

    @lan.setter
    def lan(self, lan):
        """Sets the lan of this NicProperties.

        The LAN ID the NIC will be on. If the LAN ID does not exist, it will be implicitly created.  # noqa: E501

        :param lan: The lan of this NicProperties.  # noqa: E501
        :type lan: int
        """
        if self.local_vars_configuration.client_side_validation and lan is None:  # noqa: E501
            raise ValueError("Invalid value for `lan`, must not be `None`")  # noqa: E501

        self._lan = lan

    @property
    def mac(self):
        """Gets the mac of this NicProperties.  # noqa: E501

        The MAC address of the NIC.  # noqa: E501

        :return: The mac of this NicProperties.  # noqa: E501
        :rtype: str
        """
        return self._mac

    @mac.setter
    def mac(self, mac):
        """Sets the mac of this NicProperties.

        The MAC address of the NIC.  # noqa: E501

        :param mac: The mac of this NicProperties.  # noqa: E501
        :type mac: str
        """

        self._mac = mac

    @property
    def name(self):
        """Gets the name of this NicProperties.  # noqa: E501

        The name of the  resource.  # noqa: E501

        :return: The name of this NicProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NicProperties.

        The name of the  resource.  # noqa: E501

        :param name: The name of this NicProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def pci_slot(self):
        """Gets the pci_slot of this NicProperties.  # noqa: E501

        The PCI slot number for the NIC.  # noqa: E501

        :return: The pci_slot of this NicProperties.  # noqa: E501
        :rtype: int
        """
        return self._pci_slot

    @pci_slot.setter
    def pci_slot(self, pci_slot):
        """Sets the pci_slot of this NicProperties.

        The PCI slot number for the NIC.  # noqa: E501

        :param pci_slot: The pci_slot of this NicProperties.  # noqa: E501
        :type pci_slot: int
        """

        self._pci_slot = pci_slot
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NicProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NicProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ApplicationLoadBalancerForwardingRuleProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'client_timeout': 'int',

        'http_rules': 'list[ApplicationLoadBalancerHttpRule]',

        'listener_ip': 'str',

        'listener_port': 'int',

        'name': 'str',

        'protocol': 'str',

        'server_certificates': 'list[str]',
    }

    attribute_map = {

        'client_timeout': 'clientTimeout',

        'http_rules': 'httpRules',

        'listener_ip': 'listenerIp',

        'listener_port': 'listenerPort',

        'name': 'name',

        'protocol': 'protocol',

        'server_certificates': 'serverCertificates',
    }

    def __init__(self, client_timeout=None, http_rules=None, listener_ip=None, listener_port=None, name=None, protocol=None, server_certificates=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationLoadBalancerForwardingRuleProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_timeout = None
        self._http_rules = None
        self._listener_ip = None
        self._listener_port = None
        self._name = None
        self._protocol = None
        self._server_certificates = None
        self.discriminator = None

        if client_timeout is not None:
            self.client_timeout = client_timeout
        if http_rules is not None:
            self.http_rules = http_rules
        self.listener_ip = listener_ip
        self.listener_port = listener_port
        self.name = name
        self.protocol = protocol
        if server_certificates is not None:
            self.server_certificates = server_certificates


    @property
    def client_timeout(self):
        """Gets the client_timeout of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        The maximum time in milliseconds to wait for the client to acknowledge or send data; default is 50,000 (50 seconds).  # noqa: E501

        :return: The client_timeout of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: int
        """
        return self._client_timeout

    @client_timeout.setter
    def client_timeout(self, client_timeout):
        """Sets the client_timeout of this ApplicationLoadBalancerForwardingRuleProperties.

        The maximum time in milliseconds to wait for the client to acknowledge or send data; default is 50,000 (50 seconds).  # noqa: E501

        :param client_timeout: The client_timeout of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type client_timeout: int
        """

        self._client_timeout = client_timeout

    @property
    def http_rules(self):
        """Gets the http_rules of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        An array of items in the collection. The original order of rules is preserved during processing, except that rules of the 'FORWARD' type are processed after the rules with other defined actions. The relative order of the 'FORWARD' type rules is also preserved during the processing.  # noqa: E501

        :return: The http_rules of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: list[ApplicationLoadBalancerHttpRule]
        """
        return self._http_rules

    @http_rules.setter
    def http_rules(self, http_rules):
        """Sets the http_rules of this ApplicationLoadBalancerForwardingRuleProperties.

        An array of items in the collection. The original order of rules is preserved during processing, except that rules of the 'FORWARD' type are processed after the rules with other defined actions. The relative order of the 'FORWARD' type rules is also preserved during the processing.  # noqa: E501

        :param http_rules: The http_rules of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type http_rules: list[ApplicationLoadBalancerHttpRule]
        """

        self._http_rules = http_rules

    @property
    def listener_ip(self):
        """Gets the listener_ip of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        The listening (inbound) IP.  # noqa: E501

        :return: The listener_ip of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: str
        """
        return self._listener_ip

    @listener_ip.setter
    def listener_ip(self, listener_ip):
        """Sets the listener_ip of this ApplicationLoadBalancerForwardingRuleProperties.

        The listening (inbound) IP.  # noqa: E501

        :param listener_ip: The listener_ip of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type listener_ip: str
        """
        if self.local_vars_configuration.client_side_validation and listener_ip is None:  # noqa: E501
            raise ValueError("Invalid value for `listener_ip`, must not be `None`")  # noqa: E501

        self._listener_ip = listener_ip

    @property
    def listener_port(self):
        """Gets the listener_port of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        The listening (inbound) port number; the valid range is 1 to 65535.  # noqa: E501

        :return: The listener_port of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: int
        """
        return self._listener_port

    @listener_port.setter
    def listener_port(self, listener_port):
        """Sets the listener_port of this ApplicationLoadBalancerForwardingRuleProperties.

        The listening (inbound) port number; the valid range is 1 to 65535.  # noqa: E501

        :param listener_port: The listener_port of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type listener_port: int
        """
        if self.local_vars_configuration.client_side_validation and listener_port is None:  # noqa: E501
            raise ValueError("Invalid value for `listener_port`, must not be `None`")  # noqa: E501

        self._listener_port = listener_port

    @property
    def name(self):
        """Gets the name of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        The name of the Application Load Balancer forwarding rule.  # noqa: E501

        :return: The name of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApplicationLoadBalancerForwardingRuleProperties.

        The name of the Application Load Balancer forwarding rule.  # noqa: E501

        :param name: The name of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def protocol(self):
        """Gets the protocol of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        The balancing protocol.  # noqa: E501

        :return: The protocol of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this ApplicationLoadBalancerForwardingRuleProperties.

        The balancing protocol.  # noqa: E501

        :param protocol: The protocol of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type protocol: str
        """
        if self.local_vars_configuration.client_side_validation and protocol is None:  # noqa: E501
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501
        allowed_values = ["HTTP"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and protocol not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `protocol` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol, allowed_values)
            )

        self._protocol = protocol

    @property
    def server_certificates(self):
        """Gets the server_certificates of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501

        Array of items in the collection.  # noqa: E501

        :return: The server_certificates of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._server_certificates

    @server_certificates.setter
    def server_certificates(self, server_certificates):
        """Sets the server_certificates of this ApplicationLoadBalancerForwardingRuleProperties.

        Array of items in the collection.  # noqa: E501

        :param server_certificates: The server_certificates of this ApplicationLoadBalancerForwardingRuleProperties.  # noqa: E501
        :type server_certificates: list[str]
        """

        self._server_certificates = server_certificates
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationLoadBalancerForwardingRuleProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationLoadBalancerForwardingRuleProperties):
            return True

        return self.to_dict() != other.to_dict()
